import { Plugin as VitePlugin } from 'vite';
import { Plugin as SvgoPluginFunction } from 'svgo/lib/types';
import '../ambient.d.ts';
export type SvgoPlugin<Params = {}> = {
    name: string;
    params?: Params;
    fn: SvgoPluginFunction<Params>;
};
export type FileNameParserInput = {
    /** Filename without extension. */
    filename: string;
    /** Query string specified in module import. */
    query: string;
    /** Full file path. */
    filePath: string;
    /** Full module id. */
    moduleId: string;
};
export type PluginOptions = {
    /** Default icon prefix. Default value: 'cu'. Short for custom. */
    prefix?: string;
    /** If first word of filename starts with the prefix option, it will treat the first whole word as the prefix. */
    inferPrefix?: boolean;
    /** Overrides filename parsing and transform. */
    fileNameParser?: (input: FileNameParserInput) => {
        prefix?: string;
        iconName: string;
        aliases?: string[];
    };
    /** Add plugins to be given to svgo. When options is given as array, the plugins are run before. */
    svgoPlugins?: SvgoPlugin[] | {
        before: SvgoPlugin[];
        after: SvgoPlugin[];
    };
};
declare const svgFontawesomeIconLoader: (pluginOptions?: PluginOptions) => VitePlugin;
export default svgFontawesomeIconLoader;
